.. This file provides the instructions for how to display the API documentation generated using sphinx autodoc
   extension. Use it to declare Python documentation sub-directories via appropriate modules (autodoc, etc.).

Utilities Module
================
.. automodule:: ataraxis_base_utilities.utilities
   :members:
   :undoc-members:
   :show-inheritance:
